@@ -3,7 +3,7 @@ package Promise::ES6;
 use strict;
 use warnings;
 
-our $VERSION = '0.23_01';
+our $VERSION = '0.24';
 
 =encoding utf-8
 
@@ -41,6 +41,12 @@ Promise::ES6 - ES6-style promises in Perl
 
 =head1 DESCRIPTION
 
+=begin html
+
+<a href='https://coveralls.io/github/FGasper/p5-Promise-ES6?branch=master'><img src='https://coveralls.io/repos/github/FGasper/p5-Promise-ES6/badge.svg?branch=master' alt='Coverage Status' /></a>
+
+=end html
+
 This module provides a Perl implementation of L<promises|https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Using_promises>, a useful pattern
 for coordinating asynchronous tasks.
 
@@ -68,6 +74,9 @@ not a list.
 =item * Unhandled rejections are reported via C<warn()>. (See below
 for details.)
 
+=item * Undefined or empty rejection values trigger a warning.
+This provides the same value as Perl’s own warning on C<die(undef)>.
+
 =item * The L<Promises/A+ test suite|https://github.com/promises-aplus/promises-tests> avoids testing the case where an “executor”
 function’s resolve callback itself receives another promise, e.g.:
 
@@ -90,6 +99,32 @@ Future is not compatible with promises.
 
 (See L<Promise::ES6::Future> for more tools to interact with L<Future>.)
 
+=head1 B<EXPERIMENTAL:> ASYNC/AWAIT SUPPORT
+
+This module implements L<Future::AsyncAwait::Awaitable>. This lets you do
+nifty stuff like:
+
+    use Future::AsyncAwait;
+
+    async sub do_stuff {
+        my $foo = await fetch_number_p();
+
+        # NB: The real return is a promise that provides this value:
+        return 1 + $foo;
+    }
+
+    my $one_plus_number = await do_stuff();
+
+… which roughly equates to:
+
+    sub do_stuff {
+        return fetch_number_p()->then( sub { 1 + $foo } );
+    }
+
+    do_stuff->then( sub {
+        $one_plus_number = shift;
+    } );
+
 =head1 UNHANDLED REJECTIONS
 
 This module’s handling of unhandled rejections has changed over time.
@@ -201,6 +236,8 @@ a canceled query in the “pending” state or to “settle” (i.e., resolve or
 reject) it. All things being equal, I feel the first approach is the most
 intuitive, while the latter ends up being “cleaner”.
 
+Of note: L<Future> implements native cancellation.
+
 =head1 MEMORY LEAKS
 
 It’s easy to create inadvertent memory leaks using promises in Perl.
@@ -275,7 +312,7 @@ mine are the nicest :), but YMMV. Enjoy!
 
 =head1 LICENSE & COPYRIGHT
 
-Copyright 2019-2020 Gasper Software Consulting.
+Copyright 2019-2021 Gasper Software Consulting.
 
 This library is licensed under the same terms as Perl itself.
 
